==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/model/MessageClient.java <==
package cn.gtmap.realestate.supervise.model;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author <a href="mailto:tianjian@gtmap.cn">tianjian</a>
 * @version 1.0, 2017/3/23
 * @description 客户端发送消息封装
 */
public class MessageClient implements Serializable{

    //客户端消息队列的名称
    private String clientName;
    //状态
    private String status;
    //发送方地区编码
    private String form;

    private String password;

    //消息队列的名称
    private String queueName;
    //每次扫描将数据全部放到这边
    private List<FileMessage> fileMessages;

    //发送消息的时间
    private Date sendTime;

    //发送到省或者国家级服务器的名称
    private String serverName;

    //日志记录表主键ID
    private String fileId;

    //保存到ES中的ID
    private String ywbwId;

    public String getYwbwId() {
        return ywbwId;
    }

    public void setYwbwId(String ywbwId) {
        this.ywbwId = ywbwId;
    }

    //JSON工具需要
    public MessageClient() {
    }

    public Date getSendTime() {
        return sendTime;
    }

    public String getQueueName() {
        return queueName;
    }

    public String getServerName() {
        return serverName;
    }

    public String getStatus() {
        return status;
    }

    public String getForm() {
        return form;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public void setForm(String form) {
        this.form = form;
    }

    public void setQueueName(String queueName) {
        this.queueName = queueName;
    }

    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public List<FileMessage> getFileMessages() {
        return fileMessages;
    }

    public void setFileMessages(List<FileMessage> fileMessages) {
        this.fileMessages = fileMessages;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getClientName() {
        return clientName;
    }

    public void setClientName(String clientName) {
        this.clientName = clientName;
    }

    public String getFileId() {
        return fileId;
    }

    public void setFileId(String fileId) {
        this.fileId = fileId;
    }
}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/model/MessageClient.java <==
package cn.gtmap.realestate.supervise.model;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author <a href="mailto:tianjian@gtmap.cn">tianjian</a>
 * @version 1.0, 2017/3/23
 * @description 客户端发送消息封装
 */
public class MessageClient implements Serializable{

    //客户端消息队列的名称
    private String clientName;
    //状态
    private String status;
    //发送方地区编码
    private String form;

    private String password;

    //消息队列的名称
    private String queueName;
    //每次扫描将数据全部放到这边
    private List<FileMessage> fileMessages;

    //发送消息的时间
    private Date sendTime;

    //发送到省或者国家级服务器的名称
    private String serverName;

    //日志记录表主键ID
    private String fileId;

    //保存到ES中的ID
    private String ywbwId;

    // 报文来源（1：地籍报文，2：登记报文）
    private String bwly;

    public String getYwbwId() {
        return ywbwId;
    }

    public void setYwbwId(String ywbwId) {
        this.ywbwId = ywbwId;
    }

    //JSON工具需要
    public MessageClient() {
    }

    public Date getSendTime() {
        return sendTime;
    }

    public String getQueueName() {
        return queueName;
    }

    public String getServerName() {
        return serverName;
    }

    public String getStatus() {
        return status;
    }

    public String getForm() {
        return form;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public void setForm(String form) {
        this.form = form;
    }

    public void setQueueName(String queueName) {
        this.queueName = queueName;
    }

    public void setSendTime(Date sendTime) {
        this.sendTime = sendTime;
    }

    public List<FileMessage> getFileMessages() {
        return fileMessages;
    }

    public void setFileMessages(List<FileMessage> fileMessages) {
        this.fileMessages = fileMessages;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getClientName() {
        return clientName;
    }

    public void setClientName(String clientName) {
        this.clientName = clientName;
    }

    public String getFileId() {
        return fileId;
    }

    public void setFileId(String fileId) {
        this.fileId = fileId;
    }

    public String getBwly() {
        return bwly;
    }

    public void setBwly(String bwly) {
        this.bwly = bwly;
    }
}
